@@ -1,4 +1,4 @@
-.TH KDB 8 "June 4, 2004"
+.TH KDB 8 "September 17, 2004"
 .hy 0
 .SH NAME
 Built-in Kernel Debugger for Linux - v4.4
@@ -144,6 +144,7 @@ ll	Follow Linked Lists
 lsmod	List loaded modules
 md	Display memory contents
 mdWcN	Display memory contents with width W and count N.
+mdp	Display memory based on a physical address
 mdr	Display raw memory contents
 mds	Display memory contents symbolically
 mm	Modify memory contents, words
@@ -158,6 +159,7 @@ set	Add/change environment variable
 sr	Invoke SysReq commands
 ss	Single step a cpu
 ssb	Single step a cpu until a branch instruction
+stackdepth	Print the stack depth for selected processes
 summary	Summarize the system
 .TE
 .DE
@@ -290,6 +292,13 @@ It is also used when dumping user pages.
 reboot
 Reboot the system, with no attempt to do a clean close down.
 .TP 8
+stackdepth <percentage>
+Print the stack usage for processes using more than the specified
+percentage of their stack.
+If percentage is not supplied, it defaults to 60.
+This command is only implemented on i386 and ia64 architectures,
+patches for other architectures will be gratefully accepted.
+.TP 8
 summary
 Print a summary of the system, including the time (no timezone is
 applied), uname information and various critical system counters.
